@@ -25,10 +25,9 @@ typedef unsigned int NSUInteger;
 char *mac_fname_to_roman(const char *in);
 void fl_ringbell(int a);
 extern "C" {
-	char *MG_GetBundleResourcesDir(void);
+	const char *MG_GetBundleResourcesDir(void);
 	void PtoC(const void *in, void *out);
 	void CtoP(const void *in, void *out);
-	void MGinit_apple_events(void);
 	void show_apropos(Fl_Widget *, void *unused);
 	void MG_apple_inits(void);
 }
@@ -60,8 +59,6 @@ void draw_rotated_string(const char *txt, int x, int y, float degrees /*clockwis
 /* extern functions */
 extern void hide_window_callback(Fl_Widget *ob, void *data);
 extern char *get_res_value(const char *name, const char *def_value);
-extern Fl_Window *use_initial_file(SEA_VIEW *view, char *masename, int doing_dnd);
-extern char *get_next_help_line(void *in, char *line, int lline);
 extern int printout_block, printout_fontsize;
 extern int printout_vary, printout_black;
 extern paperformat printout_pageformat;
@@ -131,17 +128,9 @@ void kill_last_desc(pid_t ascend)
 }
 */
 
-char *MG_GetBundleResourcesDir(void)
+const char *MG_GetBundleResourcesDir(void)
 {
-  ProcessSerialNumber psn;
-  FSRef fsref;
-  static char fname[300];
-  
-  GetCurrentProcess(&psn);
-  GetProcessBundleLocation(&psn, &fsref);
-  FSRefMakePath(&fsref, (UInt8 *)fname, sizeof(fname)-1);
-  strcat(fname, "/Contents/Resources"); 
-  return fname;
+  return [[[NSBundle mainBundle] resourcePath] UTF8String];
 }
 
 
@@ -352,7 +341,7 @@ void MG_apple_inits(void)
 void set_seaview_modified(SEA_VIEW *view, int ismodified)
 {
   view->modif_but_not_saved = ismodified;
-  [(NSWindow*)(Fl_X::i(view->dnawin)->xid) setDocumentEdited:ismodified];
+  [(NSWindow*)(fl_xid(view->dnawin)) setDocumentEdited:ismodified];
 }
 
 #if !__LP64__
@@ -492,7 +481,6 @@ void *MG_PrepareCopy(int w, int h)
   myrect.left=0;
   myrect.right=w;
   myrect.bottom=h;
-  Fl_X::q_release_context();
   PicHandle mypicture = OpenPicture(&myrect);
   ClipRect(&myrect);
   PenNormal();
@@ -600,7 +588,7 @@ void MyCopyPictToClipboard (PicHandle mypicture)
 //next 2 functions copy quartz data to clipboard both as pdf and as PICT (or tiff for 64-bit) bitmap
 void *prepare_copy_pdf_and_pict(int w, int h)
 {
-  Fl_X::q_release_context();
+  if (fl_gc) CGContextRestoreGState(fl_gc);
   //prepare to draw in pdf context
   CGRect bounds = CGRectMake(0, 0, w, h );	
   CFMutableDataRef pdfdata = CFDataCreateMutable(NULL, 0);
