@@ -14,7 +14,7 @@ void delete_res_value(const char *name);
 
 
 #if defined(__APPLE__)
-#include <Carbon/Carbon.h>
+#include <ApplicationServices/ApplicationServices.h>
 
 /* for Mac OS X */
 char *get_res_value(const char *name, const char *def_value)
