@@ -244,7 +244,7 @@ typedef struct _SEA_VIEW {
 
 typedef struct _props_menu_parts {
 	int fontsize, colors, viewasprots, inverted, edit, reference, keys,
-		consensusopt, slow_fast, allow_lower, custom;
+		consensusopt, slow_fast, allow_lower, custom, stats;
 	SEA_VIEW *view;
 	int usingcodoncolors;
 	} props_menu_parts;
@@ -317,7 +317,7 @@ extern int get_color_for_aa( int key );
 extern char **prepcolranks(char **seq, int totseqs, int maxlen, int *eachlength,
 	int (*calc_color_function)( int ), int numb_gc, int allow_lower);
 extern char complement_base(char old);
-extern void select_deselect_seq(SEA_VIEW *view, int new_seq);
+extern void select_deselect_seq(SEA_VIEW *view, int new_seq, int from_tree = 0);
 extern void save_active_region(SEA_VIEW *view);
 extern void align_selected_parts(SEA_VIEW *view, int align_algorithm, align_choice my_align_choice);
 extern void free_region(region *reg);
