@@ -221,7 +221,7 @@ void refresh(char** seq, int nbseq, int option, int prot)
 void reg_and_pos(SEA_VIEW *view, int *selected, list_segments* active)
 { 
   
-  int sel1=0, sel2=0, sel3=0, i, cur_reg_deb=0;
+  int sel1=0, sel2=0, sel3=0, i /*, cur_reg_deb=0*/;
   int lgseq = view->seq_length;
   list_segments start_end = {0, lgseq-1, NULL};
   if (active == NULL) active = &start_end;
